/******************************************************************************/
/* LCD.h Text LCD function prototypes                                         */
/******************************************************************************/
/* This file is part of the uVision/ARM development tools.                    */
/* Copyright (c) 2005-2007 Keil Software. All rights reserved.                */
/* This software may only be used under the terms of a valid, current,        */
/* end user licence from KEIL for a compatible version of KEIL software       */
/* development tools. Nothing else gives you the right to use this software.  */
/******************************************************************************/
#ifndef __LCD1602_H
#define __LCD1602_H

/*********************** Hardware specific configuration **********************/

/*------------------------- Speed dependant settings -------------------------*/

/* If processor works on high frequency delay has to be increased, it can be 
   increased by factor 2^N by this constant                                   */
#define DELAY_2N     0

/*------------------------- Text LCD size definitions ------------------------*/

#define LineLen     16                  /* Width (in characters)              */
#define NumLines     2                  /* Hight (in lines)                   */

/*-------------------- LCD interface hardware definitions --------------------*/

/* PINS: 
   - DB4 = 	 PB12
   - DB5 = 	 PB13      
   - DB6 = 	 PB14
   - DB7 = 	 PB15
   - E   =   PB5
   - RW  =   PB6
   - RS  =   PB7                                                  */

#define PIN_E                 (   1 << 5)
#define PIN_RW                (   1 << 6)
#define PIN_RS                (   1 << 7)
#define PINS_CTRL             0x00E0
#define PINS_DATA             0xF000
#define PINS_ALL              (PINS_CTRL | PINS_DATA)

/* Enable Clock for peripheral driving LCD pins                               */
#define LCD_CLOCK_EN          RCC_APB2PeriphClockCmd (RCC_APB2Periph_GPIOB, ENABLE);

/* pin E  setting to 0 or 1                                                   */
#define LCD_E(x)              GPIOB->ODR = (GPIOB->ODR & ~PIN_E)  | (x ? PIN_E : 0);
/* pin RW setting to 0 or 1                                                   */
#define LCD_RW(x)             GPIOB->ODR = (GPIOB->ODR & ~PIN_RW) | (x ? PIN_RW : 0);
/* pin RS setting to 0 or 1                                                   */
#define LCD_RS(x)             GPIOB->ODR = (GPIOB->ODR & ~PIN_RS) | (x ? PIN_RS : 0);

/* Reading DATA pins                                                          */
							   
#define LCD_DATA_IN          (((GPIOB->IDR & PINS_DATA) >> 12) & 0x0F)
/* Writing value to DATA pins                                                 */
																		  
#define LCD_DATA_OUT(x)       GPIOB->ODR = (GPIOB->ODR & ~PINS_DATA) | ((x) << 12);
																			   
/* Setting all pins to output mode                                            */
#define LCD_ALL_DIR_OUT       GPIOB->CRL = (GPIOB->CRL & 0x000FFFFF) | 0x33300000; \
                              GPIOB->CRH = (GPIOB->CRH & 0x0000FFFF) | 0x33330000;
 
/* Setting DATA pins to input mode                                            */
#define LCD_DATA_DIR_IN       GPIOB->CRH = (GPIOB->CRH & 0x0000FFFF) | 0x44440000;

/* Setting DATA pins to output mode                                           */
#define LCD_DATA_DIR_OUT      GPIOB->CRH = (GPIOB->CRH & 0x0000FFFF) | 0x33330000;

/******************************************************************************/

void delay (int cnt);
unsigned char lcd_read_status (void);
unsigned char wait_while_busy (void);
void lcd_write_4bit (unsigned char c);
void lcd_write_cmd (unsigned char c);
void lcd_write_data (unsigned char c);	  
void lcd_putchar (char c);

void lcd_init (void);
void lcd_clear (void);
void set_cursor (int column, int line);	 
void lcd_print_S (char *string);
void lcd_print_N (u16 x);
//void lcd_bargraph (int pos_x, int pos_y, int value);

#endif /* __LCD1602_H */
/******************************************************************************/

