/******************** (C) COPYRIGHT 2009 STMicroelectronics ********************
* File Name          : main.c
* Author             : MCD Application Team
* Version            : V1.0
* Date               : 08/09/2009
* Description        : Main program body
********************************************************************************
* THE PRESENT SOFTWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE TIME.
* AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY DIRECT,
* INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE
* CONTENT OF SUCH SOFTWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING
* INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*******************************************************************************/

/* Includes ------------------------------------------------------------------*/
#include "stm32f10x_lib.h"

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
ErrorStatus  HSEStartUpStatus;

/* Private function prototypes -----------------------------------------------*/
void  Delay_Ms(u16 time);

void  RCC_Configuration(void);
void  GPIO_Configuration(void);
void  NVIC_Configuration(void);
void WriteToBackupReg(u16 FirstBackupData);
u8 CheckBackupReg(u16 FirstBackupData);
u8 IsBackupRegReset(void);

extern void lcd_init     (void);
extern void lcd_clear    (void);
extern void lcd_putchar  (char c);
extern void set_cursor   (int column, int line);
extern void lcd_print    (char *string);
extern void lcd_bargraph (int pos_x, int pos_y, int value);   // STM32 Initialization

/* Private functions ---------------------------------------------------------*/ 
/*******************************************************************************
* Function Name  : main
* Description    : Main program.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
int main(void)
{
#ifdef DEBUG
  	debug();
#endif

	u8 lcd[10],key;

  	/* System Clocks Configuration */
  	RCC_Configuration();
 
  	/* NVIC configuration */
  	NVIC_Configuration();

  	/* Configure the GPIOs */
  	GPIO_Configuration();

	lcd_init();
    lcd_clear();
    lcd_print_S(" STM32_BKP !");
    Delay_Ms(10); 
     
  	/* Enable PWR and BKP clock */ // ʹAPB1ʱ 
  	RCC_APB1PeriphClockCmd(RCC_APB1Periph_PWR | RCC_APB1Periph_BKP, ENABLE);

  	/* Enable write access to Backup domain */
  	PWR_BackupAccessCmd(ENABLE); // ʹRTCͺ󱸼Ĵ 

  	/* Clear Tamper pin Event(TE) pending flag */
	BKP_ClearFlag(); // ܽ¼Ĵ־λ  

  	/* Tamper pin active on low level */ // ܽŵĵ͵ƽЧ 
//  	BKP_TamperPinLevelConfig(BKP_TamperPinLevel_Low); 

  	/* Enable Tamper interrupt */
 // 	BKP_ITConfig(ENABLE); // ʹж 

  	/* Enable Tamper pin */	// 󱸼Ĵݻضʧ 
 // 	BKP_TamperPinCmd(ENABLE); // ʹܹܽŵ⹦ 
   
  	/* Write data to Backup DRx registers */
// 	WriteToBackupReg(0x0030); // 󱸼Ĵдû 

  	/* Check if the written data are correct */	// ȷϺ󱸼Ĵ  
  	if(CheckBackupReg(0x0030) == 0x00)	// ȷ 
  	{
		/* Turn on led connected to PB.08 */
//    	GPIO_Write(GPIOB, GPIO_Pin_8);
  	}
  	else  // ݴ 
  	{
    	/* Turn on led connected to PB.09 */
 //   	GPIO_Write(GPIOB, GPIO_Pin_9);
  	}

/*	Delay_Ms(100);

	lcd[0] = BKP_ReadBackupRegister(BKP_DR1);
	lcd[1] = BKP_ReadBackupRegister(BKP_DR2);
	lcd[2] = BKP_ReadBackupRegister(BKP_DR3);
	lcd[3] = BKP_ReadBackupRegister(BKP_DR4);
	lcd[4] = BKP_ReadBackupRegister(BKP_DR5);
	lcd[5] = BKP_ReadBackupRegister(BKP_DR6);
	lcd[6] = BKP_ReadBackupRegister(BKP_DR7);
	lcd[7] = BKP_ReadBackupRegister(BKP_DR8);
	lcd[8] = BKP_ReadBackupRegister(BKP_DR9);
	lcd[9] = BKP_ReadBackupRegister(BKP_DR10);

	set_cursor(0,1);
    lcd_print_S(lcd);
	set_cursor(10,1);
	lcd_print_S("   ");
 */

//////  excamp2  /////////////
	/* Check if the Power On Reset flag is set */
  	if(RCC_GetFlagStatus(RCC_FLAG_PORRST) != RESET)	// POR/PDRλ־λ 
  	{
    	/* Clear reset flags */
    	RCC_ClearFlag(); // RCCĸλ־λ 

    	/* Turn on led connected to PC.08 */
    	GPIO_SetBits(GPIOB, GPIO_Pin_8);
   
    	/* Check if Backup data registers are programmed */
    	if(CheckBackupReg(0x0030) == 0x00)
    	{ /* Backup data registers values are correct */

      		/* Turn on led connected to PC.06 */
      		GPIO_SetBits(GPIOB, GPIO_Pin_9);
    	}
    	else
    	{ /* Backup data registers values are not correct or they are not yet
         	programmed (when the first time the program is executed) */

      		/* Write data to Backup data registers */
      		WriteToBackupReg(0x0030);

      		/* Turn on led connected to PC.07 */
      		GPIO_SetBits(GPIOB, GPIO_Pin_10);
    	}
  	}

  	/* Turn on led connected to PC.09 */
  	GPIO_SetBits(GPIOB, GPIO_Pin_11); 

	while (1)
  	{
	
  	}
}

/*******************************************************************************
* Function Name  : Delay_Ms
* Description    : delay 1 ms.
* Input          : time (ms)
* Output         : None
* Return         : None
*******************************************************************************/
void Delay_Ms(u16 time)  //ʱ
{ 
	u16 i,j;
	for(i=0;i<time;i++)
  		for(j=0;j<10260;j++)
    		;
}

/*******************************************************************************
* Function Name  : RCC_Configuration
* Description    : Configures the different system clocks.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void RCC_Configuration(void)
{
 /*  ʹڲRC */
/*	RCC_HSICmd(ENABLE);//ʹڲپ ;
 	RCC_SYSCLKConfig(RCC_SYSCLKSource_HSI);//ѡڲʱΪϵͳʱSYSCLOCK=8MHZ	
	RCC_HCLKConfig(RCC_SYSCLK_Div1);//ѡHCLKʱԴΪϵͳʱSYYSCLOCK
  	RCC_PCLK1Config(RCC_HCLK_Div4);//APB1ʱΪ2M 
  	RCC_PCLK2Config(RCC_HCLK_Div4);//APB2ʱΪ2M
  	RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOB , ENABLE);//ʹAPB2GPIOBʱ
*/

 /*  ʹⲿRC */
	/* RCC system reset(for debug purpose) */
  	RCC_DeInit();

  	/* Enable HSE */
  	RCC_HSEConfig(RCC_HSE_ON);

  	/* Wait till HSE is ready */
  	while (RCC_GetFlagStatus(RCC_FLAG_HSERDY) == RESET);

    /* Enable Prefetch Buffer */
    FLASH_PrefetchBufferCmd(FLASH_PrefetchBuffer_Enable);

    /* Flash 2 wait state */
    FLASH_SetLatency(FLASH_Latency_2);
 
    /* HCLK = SYSCLK */
    RCC_HCLKConfig(RCC_SYSCLK_Div1);
  
    /* PCLK2 = HCLK */
    RCC_PCLK2Config(RCC_HCLK_Div1);

    /* PCLK1 = HCLK/2 */
    RCC_PCLK1Config(RCC_HCLK_Div2);

    /* PLLCLK = 8MHz * 9 = 72 MHz */
    RCC_PLLConfig(RCC_PLLSource_HSE_Div1, RCC_PLLMul_9);

    /* Enable PLL */ 
    RCC_PLLCmd(ENABLE);

    /* Wait till PLL is ready */
    while(RCC_GetFlagStatus(RCC_FLAG_PLLRDY) == RESET);

    /* Select PLL as system clock source */
    RCC_SYSCLKConfig(RCC_SYSCLKSource_PLLCLK);

    /* Wait till PLL is used as system clock source */
    while(RCC_GetSYSCLKSource() != 0x08);

  	/* Enable GPIOA,GPIOB, clocks */
  	RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOA | RCC_APB2Periph_GPIOB , ENABLE);
}

/*******************************************************************************
* Function Name  : NVIC_Configuration
* Description    : Configures the nested vectored interrupt controller.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void NVIC_Configuration(void)
{
  	NVIC_InitTypeDef NVIC_InitStructure;

#ifdef  VECT_TAB_RAM  
  	/* Set the Vector Table base location at 0x20000000 */ 
  	NVIC_SetVectorTable(NVIC_VectTab_RAM, 0x0); 
#else  /* VECT_TAB_FLASH  */
  	/* Set the Vector Table base location at 0x08000000 */ 
  	NVIC_SetVectorTable(NVIC_VectTab_FLASH, 0x0);   
#endif
  
  	/* Enable TAMPER IRQChannel */
  	NVIC_InitStructure.NVIC_IRQChannel = TAMPER_IRQChannel;	//  ʹIRQ۸жͨ ;
  	NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 0; // ռȼ 0 
  	NVIC_InitStructure.NVIC_IRQChannelSubPriority = 0;	 // ȼ 0 
  	NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;	// IRQͨʹ 
  	NVIC_Init(&NVIC_InitStructure);
}

/*******************************************************************************
* Function Name  : GPIO_Configuration
* Description    : Configures the different GPIO ports.
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void GPIO_Configuration(void)
{
  	GPIO_InitTypeDef GPIO_InitStructure;

	GPIO_InitStructure.GPIO_Pin	= GPIO_Pin_8|GPIO_Pin_9|GPIO_Pin_10|GPIO_Pin_11;//ѡPX.8-11
  	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;	//ܽƵΪ50MHZ
  	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;	//ģʽΪ
  	GPIO_Init(GPIOB, &GPIO_InitStructure);   //ʼGPIOBĴ

	GPIO_InitStructure.GPIO_Pin	= GPIO_Pin_0|GPIO_Pin_8;//ѡPX.0 8
  	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;//ܽƵΪ50MHZ
  	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IPD;//Ϊ
  	GPIO_Init(GPIOA , &GPIO_InitStructure);//ʼGPIOAĴ
}

#ifdef  DEBUG
/*******************************************************************************
* Function Name  : assert_failed
* Description    : Reports the name of the source file and the source line number
*                  where the assert_param error has occurred.
* Input          : - file: pointer to the source file name
*                  - line: assert_param error line source number
* Output         : None
* Return         : None
*******************************************************************************/
void assert_failed(u8* file, u32 line)
{ 
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

  /* Infinite loop */
  	while (1)
  	{
  	}
}
#endif

/*******************************************************************************
* Function Name  : WriteToBackupReg
* Description    : Writes data Backup DRx registers.
* Input          : FirstBackupData: data to be written to Backup data registers.
* Output         : None
* Return         : None
*******************************************************************************/
void WriteToBackupReg(u16 FirstBackupData)
{
  	/* ָĺ󱸼Ĵдû */
	BKP_WriteBackupRegister(BKP_DR1, FirstBackupData);
  	BKP_WriteBackupRegister(BKP_DR2, BKP->DR1 + 0x01);
  	BKP_WriteBackupRegister(BKP_DR3, BKP->DR2 + 0x02);
  	BKP_WriteBackupRegister(BKP_DR4, BKP->DR3 + 0x03);
  	BKP_WriteBackupRegister(BKP_DR5, FirstBackupData + 0x04);
  	BKP_WriteBackupRegister(BKP_DR6, FirstBackupData + 0x05);
  	BKP_WriteBackupRegister(BKP_DR7, FirstBackupData + 0x06);
  	BKP_WriteBackupRegister(BKP_DR8, FirstBackupData + 0x07);
  	BKP_WriteBackupRegister(BKP_DR9, FirstBackupData + 0x08);
  	BKP_WriteBackupRegister(BKP_DR10, FirstBackupData + 0x09);
}

/*******************************************************************************
* Function Name  : CheckBackupReg
* Description    : Checks if the Backup DRx registers values are correct or not.
* Input          : FirstBackupData: data to be compared with Backup data registers.
* Output         : None
* Return         : - 0: All Backup DRx registers values are correct
*                  - Value different from 0: Number of the first Backup register
*                    which value is not correct
*******************************************************************************/
u8 CheckBackupReg(u16 FirstBackupData)
{
  	/* ָĺ󱸼Ĵж */
	if(BKP_ReadBackupRegister(BKP_DR1) != FirstBackupData) return 1;
  	if(BKP_ReadBackupRegister(BKP_DR2) != (BKP->DR1 + 0x01)) return 2;
  	if(BKP_ReadBackupRegister(BKP_DR3) != (BKP->DR2 + 0x02)) return 3;
  	if(BKP_ReadBackupRegister(BKP_DR4) != (BKP->DR3 + 0x03)) return 4;
  	if(BKP_ReadBackupRegister(BKP_DR5) != (FirstBackupData + 0x04)) return 5;
  	if(BKP_ReadBackupRegister(BKP_DR6) != (FirstBackupData + 0x05)) return 6;
  	if(BKP_ReadBackupRegister(BKP_DR7) != (FirstBackupData + 0x06)) return 7;
  	if(BKP_ReadBackupRegister(BKP_DR8) != (FirstBackupData + 0x07)) return 8;
  	if(BKP_ReadBackupRegister(BKP_DR9) != (FirstBackupData + 0x08)) return 9;
  	if(BKP_ReadBackupRegister(BKP_DR10) != (FirstBackupData+ 0x09)) return 10;

  	return 0;
}

/*******************************************************************************
* Function Name  : IsBackupRegReset
* Description    : Checks if the Backup DRx registers are reset or not.
* Input          : None
* Output         : None
* Return         : - 0: All Backup DRx registers are reset
*                  - Value different from 0: Number of the first Backup register
*                    not reset
*******************************************************************************/
u8 IsBackupRegReset(void)
{
  	if(BKP_ReadBackupRegister(BKP_DR1) != 0x0000) return 1;
  	if(BKP_ReadBackupRegister(BKP_DR2) != 0x0000) return 2;
  	if(BKP_ReadBackupRegister(BKP_DR3) != 0x0000) return 3;
  	if(BKP_ReadBackupRegister(BKP_DR4) != 0x0000) return 4;
  	if(BKP_ReadBackupRegister(BKP_DR5) != 0x0000) return 5;
  	if(BKP_ReadBackupRegister(BKP_DR6) != 0x0000) return 6;
  	if(BKP_ReadBackupRegister(BKP_DR7) != 0x0000) return 7;
  	if(BKP_ReadBackupRegister(BKP_DR8) != 0x0000) return 8;
  	if(BKP_ReadBackupRegister(BKP_DR9) != 0x0000) return 9;
  	if(BKP_ReadBackupRegister(BKP_DR10) != 0x0000) return 10;

  	return 0;
}

/******************* (C) COPYRIGHT 2009 STMicroelectronics *****END OF FILE****/
